Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(117)

Unified Diff: components/subresource_filter/content/browser/subresource_filter_client.h

Issue 2795053002: [subresource_filter] Implement the "Smart" UI on Android (Closed)
Patch Set: raymes review Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/subresource_filter/content/browser/subresource_filter_client.h
diff --git a/components/subresource_filter/content/browser/subresource_filter_client.h b/components/subresource_filter/content/browser/subresource_filter_client.h
index b9be5a5c8310a6bb97827b308acfc02bb1fb687d..d62e0151c7d658177b693e04a51a8569811060ab 100644
--- a/components/subresource_filter/content/browser/subresource_filter_client.h
+++ b/components/subresource_filter/content/browser/subresource_filter_client.h
@@ -11,6 +11,8 @@ class GURL;
namespace subresource_filter {
+struct ActivationState;
+
class SubresourceFilterClient {
public:
virtual ~SubresourceFilterClient() = default;
@@ -25,13 +27,17 @@ class SubresourceFilterClient {
// Returns true if the given URL is whitelisted from activation via content
// settings. This should only be called for main frame URLs.
- virtual bool IsWhitelistedByContentSettings(const GURL& url) = 0;
+ virtual bool IsWhitelistedByContentSettings(const GURL& top_level_url) = 0;
- // Adds |url| to the BLOCKED state via content settings for the current
- // profile.
- virtual void WhitelistByContentSettings(const GURL& url) = 0;
+ // Adds |top_level_url| to the BLOCKED state via content settings for the
+ // current profile.
+ virtual void WhitelistByContentSettings(const GURL& top_level_url) = 0;
virtual VerifiedRulesetDealer::Handle* GetRulesetDealer() = 0;
+
+ virtual void OnActivationComputed(
+ const GURL& top_level_url,
+ const ActivationState& activation_state) = 0;
};
} // namespace subresource_filter

Powered by Google App Engine
This is Rietveld 408576698